# PPC_2p_evidence_accumulation

## Dataset of "History-dependent variability in population dynamics during evidence accumulation in cortex"

This repository contains pre-processed behavioral data and neural data collected from mice performing an evidence accumulation task in a virtual reality (VR) environment. Neural data are recorded from PPC using two-photon calcium imaging. Detailed information about data collection can be found in:

Morcos A. S., Harvey C. D. 2016. History-dependent variability in population dynamics during evidence accumulation in cortex, Nature Neuroscience. doi: https://doi.org/10.1038/nn.4403

Data contained in this repository were used in:

Valente M., Pica G., Runyan C. A., Morcos A. S., Harvey C. D., Panzeri S. 2020. Correlations enhance the behavioral readout of neural population activity in association cortex. BioRxiv. doi: https://doi.org/10.1101/2020.04.03.024133

Data are available in three different versions, that differ in how data is selected, organized and processed. In decreasing order of completeness:

### Version 1 (AM*_yymmdd_processed.mat)

This data version contains one .mat file for each session (PPC) for a total of 11 sessions. Each .mat file contains a cell array called imTrials, with dimensionality equal to the number of trials. Each element of the cell array contains:
-	The field *imaging* with the following imaging data:
o	dF/F traces;
o	deconvolved traces;
o	spatial-binned deconvolved traces, averaged over 10 trial epochs described in Morcos et Harvey, Nat. Neurosci., 2016.
o	Neural variables consist of the deconvolved dF/F traces at the two-photon microscope sampling rate;
-	The field *dat* with other measured variables;
-	The field *result* with additional trial info (leftTurn, correct).

### Version 2 (data_simple_morcos_per_Epoch.mat)

This data version consists of a single .mat file that contains a matlab struct with dimension equal to the number of sessions. Each row of the structure refers to a single session and contains the following fields:
-	*Neural_data*: spatial-binned deconvolved traces, averaged over 10 trial epochs described in Morcos et Harvey, Nat. Neurosci., 2016;
-	*Stimuli*: binary array with 1 for stimuli with net evidence on the left, 0 for stimuli with net evidence on the right;
-	*Fine_evidence_last_cue*: final net evidence (difference between left and right total evidence);
-	*Choices*: binary array with 1 for trials with left turn, 0 for for trial with right turn;
-	*Lateral_speed*: spatial-binned behavioral data, averaged over the same 10 trial epochs as imaging data (described in Morcos et Harvey, Nat. Neurosci., 2016).

### Version 3 (data_simple_morcos_per_Window.mat)

This data version consists of a single .mat file that contains a matlab struct with dimension equal to the number of sessions. Each row of the structure refers to a single session and contains the following fields:
-	*Neural_data*: spatial-binned deconvolved traces, averaged over 7 turn-aligned windows of different length;
-	*Stimuli*: binary array with 1 for stimuli with net evidence on the left, 0 for stimuli with net evidence on the right;
-	*Stimuli_fine*: final net evidence (difference between left and right total evidence);
-	*Choices*: binary array with 1 for trials with left turn, 0 for for trial with right turn.
